@@ -22,7 +22,6 @@ from annofabapi.models import OrganizationMemberRole, ProjectMemberRole
 import annofabcli
 from annofabcli.common.dataclasses import WaitOptions
 from annofabcli.common.enums import FormatArgument
-from annofabcli.common.exceptions import OrganizationAuthorizationError, ProjectAuthorizationError
 from annofabcli.common.facade import AnnofabApiFacade
 from annofabcli.common.typing import InputDataSize
 
@@ -30,6 +29,9 @@ logger = logging.getLogger(__name__)
 
 DEFAULT_CSV_FORMAT = {"encoding": "utf_8_sig", "index": False}
 
+COMMAND_LINE_ERROR_STATUS_CODE = 2
+"""コマンドラインエラーが発生したときに返すステータスコード"""
+
 
 def build_annofabapi_resource_and_login(args: argparse.Namespace) -> annofabapi.Resource:
     """
@@ -56,7 +58,7 @@ def build_annofabapi_resource_and_login(args: argparse.Namespace) -> annofabapi.
 
 
 def add_parser(
-    subparsers: argparse._SubParsersAction,
+    subparsers: Optional[argparse._SubParsersAction],
     command_name: str,
     command_help: str,
     description: str,
@@ -78,6 +80,10 @@ def add_parser(
         サブコマンドのparser
 
     """
+
+    if subparsers is None:
+        subparsers = argparse.ArgumentParser().add_subparsers()
+
     parents = [create_parent_parser()] if is_subcommand else []
     parser = subparsers.add_parser(
         command_name,
@@ -85,7 +91,7 @@ def add_parser(
         description=description,
         help=command_help,
         epilog=epilog,
-        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+        formatter_class=PrettyHelpFormatter,
     )
     parser.set_defaults(command_help=parser.print_help)
     return parser
@@ -98,23 +104,14 @@ def create_parent_parser() -> argparse.ArgumentParser:
     parent_parser = argparse.ArgumentParser(add_help=False)
     group = parent_parser.add_argument_group("global optional arguments")
 
-    group.add_argument("--yes", action="store_true", help="処理中に現れる問い合わせに対して、常に'yes'と回答します。")
-
-    # EXAMPLE_CREDENTAILS = '{"user_id": "test_user", "password": "test_password"}'
-    # group.add_argument(
-    #     "--credentials",
-    #     type=str,
-    #     help=f"AnnoFabにログインするユーザの認証情報をJSON形式で指定します。"
-    #     f"(ex) `{EXAMPLE_CREDENTAILS}` ."
-    #     f"`file://`を先頭に付けると、JSON形式のファイルを指定できます。",
-    # )
+    group.add_argument("--yes", action="store_true", help="処理中に現れる問い合わせに対して、常に ``yes`` と回答します。")
 
     group.add_argument(
-        "--endpoint_url", type=str, help=f"AnnoFab WebAPIのエンドポイントを指定します。指定しない場合は'{DEFAULT_ENDPOINT_URL}'です。"
+        "--endpoint_url", type=str, help=f"AnnoFab WebAPIのエンドポイントを指定します。指定しない場合は ``{DEFAULT_ENDPOINT_URL}`` です。"
     )
 
     group.add_argument(
-        "--logdir", type=str, default=".log", help="ログファイルを保存するディレクトリを指定します。指定しない場合は`.log`ディレクトリ'にログファイルが保存されます。"
+        "--logdir", type=str, default=".log", help="ログファイルを保存するディレクトリを指定します。指定しない場合は ``.log`` ディレクトリ'にログファイルが保存されます。"
     )
 
     group.add_argument("--disable_log", action="store_true", help="ログを無効にします。")
@@ -122,7 +119,7 @@ def create_parent_parser() -> argparse.ArgumentParser:
     group.add_argument(
         "--logging_yaml",
         type=str,
-        help="ロギグングの設定ファイル(YAML)を指定します。指定した場合、`--logdir`オプションは無視されます。"
+        help="ロギグングの設定ファイル(YAML)を指定します。指定した場合、 ``--logdir`` オプションは無視されます。"
         "指定しない場合、デフォルトのロギングが設定されます。"
         "設定ファイルの書き方は https://docs.python.org/ja/3/howto/logging.html 参照してください。",
     )
@@ -280,24 +277,16 @@ def build_annofabapi_resource(args: argparse.Namespace) -> annofabapi.Resource:
     if endpoint_url != DEFAULT_ENDPOINT_URL:
         logger.info(f"AnnoFab WebAPIのエンドポイントURL: {endpoint_url}")
 
-    # # コマンドライン引数から認証情報を取得する
-    # dict_credentials = annofabcli.common.cli.get_json_from_args(args.credentials)
-    # if dict_credentials is not None:
-    #     return annofabapi.build(
-    #         dict_credentials.get("user_id"), dict_credentials.get("password"), endpoint_url=endpoint_url
-    #     )
-
-    # '.netrc'ファイルから認証情報を取得する
     try:
         return annofabapi.build_from_netrc(endpoint_url)
     except AnnofabApiException:
-        logger.debug("`.netrc`ファイルにはAnnoFab認証情報が存在しなかった")
+        pass
 
     # 環境変数から認証情報を取得する
     try:
         return annofabapi.build_from_env(endpoint_url)
     except AnnofabApiException:
-        logger.debug("`環境変数`ANNOFAB_USER_ID` or  `ANNOFAB_PASSWORD`が空だった")
+        pass
 
     # 標準入力から入力させる
     login_user_id = ""
@@ -374,7 +363,7 @@ class ArgumentParser:
         '--task_id` 引数を追加
         """
         if help_message is None:
-            help_message = "対象のタスクのtask_idを指定します。" + "`file://`を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。"
+            help_message = "対象のタスクのtask_idを指定します。" + " ``file://`` を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。"
 
         self.parser.add_argument("-t", "--task_id", type=str, required=required, nargs="+", help=help_message)
 
@@ -383,7 +372,7 @@ class ArgumentParser:
         '--input_data_id` 引数を追加
         """
         if help_message is None:
-            help_message = "対象の入力データのinput_data_idを指定します。" + "`file://`を先頭に付けると、input_data_idの一覧が記載されたファイルを指定できます。"
+            help_message = "対象の入力データのinput_data_idを指定します。" + " ``file://`` を先頭に付けると、input_data_idの一覧が記載されたファイルを指定できます。"
 
         self.parser.add_argument("-i", "--input_data_id", type=str, required=required, nargs="+", help=help_message)
 
@@ -404,9 +393,9 @@ class ArgumentParser:
         """
         if help_message is None:
             help_message = (
-                "CSVのフォーマットをJSON形式で指定します。`--format`が`csv`でないときは、このオプションは無視されます。"
-                "`file://`を先頭に付けると、JSON形式のファイルを指定できます。"
-                "指定した値は、[pandas.DataFrame.to_csv](https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_csv.html) の引数として渡されます。"  # noqa: E501
+                "CSVのフォーマットをJSON形式で指定します。 ``--format`` が ``csv`` でないときは、このオプションは無視されます。"
+                " ``file://`` を先頭に付けると、JSON形式のファイルを指定できます。"
+                "指定した値は、`pandas.DataFrame.to_csv <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_csv.html>`_ の引数として渡されます。"  # noqa: E501
             )
 
         self.parser.add_argument("--csv_format", type=str, help=help_message)
@@ -432,16 +421,16 @@ class ArgumentParser:
     def add_task_query(self, required: bool = False, help_message: Optional[str] = None):
         if help_message is None:
             help_message = (
-                "タスクを絞り込むためのクエリ条件をJSON形式で指定します。指定しない場合はすべてのタスクを取得します。"
-                "`file://`を先頭に付けると、JSON形式のファイルを指定できます。"
-                "使用できるキーは、phase, phase_stage, status, user_id, account_id, no_user (bool値)  のみです。"
+                "タスクを絞り込むためのクエリ条件をJSON形式で指定します。"
+                " ``file://`` を先頭に付けると、JSON形式のファイルを指定できます。"
+                "使用できるキーは、task_id, phase, phase_stage, status, user_id, account_id, no_user (bool値)  のみです。"
             )
         self.parser.add_argument("-tq", "--task_query", type=str, required=required, help=help_message)
 
 
-class AbstracCommandCinfirmInterface(abc.ABC):
+class AbstractCommandLineWithConfirmInterface(abc.ABC):
     """
-    コマンドライン上でpromptを表示するときのインターフェイズ
+    コマンドライン上でpromptを表示するときのインターフェイス
     """
 
     def __init__(self, all_yes: bool = False):
@@ -464,17 +453,11 @@ class AbstracCommandCinfirmInterface(abc.ABC):
         return yes
 
 
-class AbstractCommandLineInterface(abc.ABC):
+class AbstractCommandLineWithoutWebapiInterface(abc.ABC):
     """
-    CLI用の抽象クラス
+    webapiにアクセスしないCLI用の抽象クラス
     """
 
-    #: annofabapi.Resourceインスタンス
-    service: annofabapi.Resource
-
-    #: AnnofabApiFacadeインスタンス
-    facade: AnnofabApiFacade
-
     #: Trueならば、処理中に現れる問い合わせに対して、常に'yes'と回答したものとして処理する。
     all_yes: bool = False
 
@@ -490,9 +473,7 @@ class AbstractCommandLineInterface(abc.ABC):
     #: 出力フォーマット
     str_format: Optional[str] = None
 
-    def __init__(self, service: annofabapi.Resource, facade: AnnofabApiFacade, args: argparse.Namespace):
-        self.service = service
-        self.facade = facade
+    def __init__(self, args: argparse.Namespace):
         self.args = args
         self.process_common_args(args)
 
@@ -517,36 +498,6 @@ class AbstractCommandLineInterface(abc.ABC):
 
         logger.info(f"args: {args}")
 
-    def validate_project(
-        self,
-        project_id,
-        project_member_roles: Optional[List[ProjectMemberRole]] = None,
-        organization_member_roles: Optional[List[OrganizationMemberRole]] = None,
-    ):
-        """
-        プロジェクト or 組織に対して、必要な権限が付与されているかを確認する。
-
-        Args:
-            project_id:
-            project_member_roles: プロジェクトメンバロールの一覧. Noneの場合はチェックしない。
-            organization_member_roles: 組織メンバロールの一覧。Noneの場合はチェックしない。
-
-        Raises:
-             AuthorizationError: 自分自身のRoleがいずれかのRoleにも合致しなければ、AuthorizationErrorが発生する。
-
-        """
-        project_title = self.facade.get_project_title(project_id)
-        logger.info(f"project_title = {project_title}, project_id = {project_id}")
-
-        if project_member_roles is not None:
-            if not self.facade.contains_any_project_member_role(project_id, project_member_roles):
-                raise ProjectAuthorizationError(project_title, project_member_roles)
-
-        if organization_member_roles is not None:
-            organization_name = self.facade.get_organization_name_from_project_id(project_id)
-            if not self.facade.contains_any_organization_member_role(organization_name, organization_member_roles):
-                raise OrganizationAuthorizationError(organization_name, organization_member_roles)
-
     def confirm_processing(self, confirm_message: str) -> bool:
         """
         `all_yes`属性を見て、処理するかどうかユーザに問い合わせる。
@@ -597,7 +548,7 @@ class AbstractCommandLineInterface(abc.ABC):
 
         return True
 
-    def search_with_jmespath_expression(self, target: Any):
+    def search_with_jmespath_expression(self, target: Any) -> Any:
         """
         インスタンスで保持しているJMespath情報で、targetの中身を探す。
         Args:
@@ -620,3 +571,49 @@ class AbstractCommandLineInterface(abc.ABC):
         annofabcli.utils.print_according_to_format(
             target, arg_format=FormatArgument(self.str_format), output=self.output, csv_format=self.csv_format
         )
+
+
+class PrettyHelpFormatter(argparse.RawTextHelpFormatter, argparse.ArgumentDefaultsHelpFormatter):
+    def _format_action(self, action: argparse.Action) -> str:
+        return super()._format_action(action) + "\n"
+
+
+class AbstractCommandLineInterface(AbstractCommandLineWithoutWebapiInterface):
+    """
+    CLI用の抽象クラス
+    """
+
+    #: annofabapi.Resourceインスタンス
+    service: annofabapi.Resource
+
+    #: AnnofabApiFacadeインスタンス
+    facade: AnnofabApiFacade
+
+    def __init__(self, service: annofabapi.Resource, facade: AnnofabApiFacade, args: argparse.Namespace):
+        self.service = service
+        self.facade = facade
+        super().__init__(args)
+
+    def validate_project(
+        self,
+        project_id,
+        project_member_roles: Optional[List[ProjectMemberRole]] = None,
+        organization_member_roles: Optional[List[OrganizationMemberRole]] = None,
+    ):
+        """
+        プロジェクト or 組織に対して、必要な権限が付与されているかを確認する。
+
+        Args:
+            project_id:
+            project_member_roles: プロジェクトメンバロールの一覧. Noneの場合はチェックしない。
+            organization_member_roles: 組織メンバロールの一覧。Noneの場合はチェックしない。
+
+        Raises:
+             AuthorizationError: 自分自身のRoleがいずれかのRoleにも合致しなければ、AuthorizationErrorが発生する。
+
+        """
+        self.facade.validate_project(
+            project_id=project_id,
+            project_member_roles=project_member_roles,
+            organization_member_roles=organization_member_roles,
+        )
