@@ -5,7 +5,6 @@ import annofabcli
 import annofabcli.common.cli
 from annofabcli.experimental import (
     dashboard,
-    find_break_error,
     list_labor_worktime,
     list_labor_worktime_from_csv,
     list_out_of_range_annotation_for_movie,
@@ -17,7 +16,6 @@ def parse_args(parser: argparse.ArgumentParser):
 
     # サブコマンドの定義
     dashboard.add_parser(subparsers)
-    find_break_error.add_parser(subparsers)
     list_labor_worktime.add_parser(subparsers)
     list_labor_worktime_from_csv.add_parser(subparsers)
     list_out_of_range_annotation_for_movie.add_parser(subparsers)
