@@ -3,11 +3,11 @@ import datetime
 import json
 import logging
 import multiprocessing
-import zipfile
+from collections import defaultdict
 from dataclasses import dataclass
 from functools import partial
 from pathlib import Path
-from typing import Any, Callable, Dict, List, Optional, Set
+from typing import Any, Dict, List, Optional, Set
 
 import annofabapi.utils
 import dateutil
@@ -15,7 +15,7 @@ import dateutil.parser
 import more_itertools
 from annofabapi.dataclass.task import Task as DcTask
 from annofabapi.models import InputDataId, Inspection, JobStatus, ProjectJobType, Task, TaskHistory
-from annofabapi.parser import SimpleAnnotationZipParser
+from annofabapi.parser import lazy_parse_simple_annotation_zip
 
 from annofabcli.common.dataclasses import WaitOptions
 from annofabcli.common.download import DownloadingFile
@@ -24,10 +24,7 @@ from annofabcli.common.facade import TaskQuery, match_task_with_query
 
 logger = logging.getLogger(__name__)
 
-InputDataDict = Dict[InputDataId, Dict[str, Any]]
-AnnotationDict = Dict[str, InputDataDict]
-AnnotationSummaryFunc = Callable[[List[Dict[str, Any]]], Dict[str, Any]]
-"""アノテーションの概要を算出する関数"""
+InputDataDict = Dict[InputDataId, int]
 
 
 def _get_task_histories_dict(api: annofabapi.AnnofabApi, project_id: str, task_id: str) -> Dict[str, List[TaskHistory]]:
@@ -114,40 +111,20 @@ class Database:
         else:
             return True
 
-    def read_annotation_summary(
-        self, task_list: List[Task], annotation_summary_func: AnnotationSummaryFunc
-    ) -> AnnotationDict:
+    def get_annotation_count_by_task(self) -> Dict[str, int]:
         logger.debug(f"{self.logging_prefix}: reading {str(self.annotations_zip_path)}")
 
-        def read_annotation_summary_per_input_data(task_id: str, input_data_id_: str) -> Dict[str, Any]:
-            json_path = f"{task_id}/{input_data_id_}.json"
-            parser = SimpleAnnotationZipParser(zip_file, json_path)
+        result: Dict[str, int] = defaultdict(int)
+        for index, parser in enumerate(lazy_parse_simple_annotation_zip(self.annotations_zip_path)):
+            if (index + 1) % 1000 == 0:
+                logger.debug(f"{self.logging_prefix}: {index+1} 件目を読み込み中")
+
             simple_annotation: Dict[str, Any] = parser.load_json()
-            return annotation_summary_func(simple_annotation["details"])
+            annotation_count = len(simple_annotation["details"])
 
-        with zipfile.ZipFile(self.annotations_zip_path, "r") as zip_file:
-            annotation_dict: AnnotationDict = {}
+            result[parser.task_id] += annotation_count
 
-            task_count = 0
-            for task in task_list:
-                task_count += 1
-                if task_count % 1000 == 0:
-                    logger.debug(f"{self.logging_prefix}: {task_count} / {len(task_list)} 件目を読み込み中")
-
-                task_id = task["task_id"]
-                input_data_id_list = task["input_data_id_list"]
-
-                try:
-                    input_data_dict: InputDataDict = {}
-                    for input_data_id in input_data_id_list:
-                        input_data_dict[input_data_id] = read_annotation_summary_per_input_data(task_id, input_data_id)
-                    annotation_dict[task_id] = input_data_dict
-                except Exception as e:  # pylint: disable=broad-except
-                    logger.warning(f"{self.logging_prefix}: task_id='{task_id}'のJSONファイル読み込みで失敗しました。")
-                    logger.warning(e)
-                    continue
-
-            return annotation_dict
+        return result
 
     def read_inspections_from_json(self, task_id_list: List[str]) -> Dict[str, Dict[InputDataId, List[Inspection]]]:
         logger.debug(f"{self.logging_prefix}: reading {self.inspection_json_path}")
@@ -574,30 +551,6 @@ class Database:
 
         return [to_new_labor(e) for e in labor_list]
 
-    @staticmethod
-    def get_not_updated_task_ids(old_tasks, new_tasks) -> Set[str]:
-        """
-        更新されていないtask_idのListを取得する
-        Args:
-            old_tasks:
-            new_tasks:
-
-        Returns:
-
-        """
-        updated_task_ids = set()
-        for new_task in new_tasks:
-            filterd_list = [e for e in old_tasks if e["task_id"] == new_task["task_id"]]
-            if len(filterd_list) == 0:
-                continue
-            old_task = filterd_list[0]
-            if dateutil.parser.parse(old_task["updated_datetime"]) == dateutil.parser.parse(
-                new_task["updated_datetime"]
-            ):
-                updated_task_ids.add(new_task["task_id"])
-
-        return updated_task_ids
-
     def get_task_histories_dict(self, all_tasks: List[Task]) -> Dict[str, List[TaskHistory]]:
         """
         Annofabからタスク履歴情報を取得する。
