@@ -13,6 +13,7 @@ import annofabcli.statistics.list_worktime
 import annofabcli.statistics.summarize_task_count
 import annofabcli.statistics.summarize_task_count_by_task_id
 import annofabcli.statistics.summarize_task_count_by_user
+import annofabcli.statistics.visualize_annotation_count
 import annofabcli.statistics.visualize_statistics
 
 
@@ -31,6 +32,7 @@ def parse_args(parser: argparse.ArgumentParser):
     annofabcli.statistics.summarize_task_count_by_task_id.add_parser(subparsers)
     annofabcli.statistics.summarize_task_count_by_user.add_parser(subparsers)
     annofabcli.statistics.visualize_statistics.add_parser(subparsers)
+    annofabcli.statistics.visualize_annotation_count.add_parser(subparsers)
 
 
 def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
